/**
 * @file
 * Provides an example to subscribe to data, notifications and api from the HAM DEX ESB using ham-dex-subscriber.
 * 
 * @author
 * Daniel
 */
var express = require('express');
var app = express();

var subscriber = require('ham-dex-subscriber');

const options = {
    "subscriber": process.env.HAM_DEX_SUBSCRIBER || "Demo-Subscriber",
    "credentials": {
        "username": process.env.HAM_DEX_USERNAME || "demo-user",
        "password": process.env.HAM_DEX_PASSWORD || "demo-password"
    },
    "esb": {
        "host": process.env.HAM_DEX_HOST || "ham-dex.local",
        "port": process.env.HAM_DEX_PORT || 3443
    },
    "callback": {
        "host": process.env.HOST || "my-dns-name.local",
        "port": process.env.PORT || 3000
    }
};

subscriber = subscriber(app, options);

// Get inventory
subscriber.getInventory("Cities", function(data) {
    console.log("Received list of cities");
});

// Change inventory
subscriber.input.put("Cities", { "country": "GM", "name": "Georgetown", "lat": "-13.54039", "lng": "14.76374" });
subscriber.input.post("Cities", { "id": "GeorgetownGM", "country": "GM", "name": "Georgetown", "lat": "13.54039", "lng": "-14.76374" });
subscriber.input.delete("Cities", "GeorgetownGM");

// Subscription to systemstatus messages
var systemstatusSubscription = subscriber.registerSubscription("systemstatus", function(method, data) {
    console.log('System status: ' + JSON.stringify(data));
});

// To check if a subscription is still active  (returns a Promise):
systemstatusSubscription.isActive().then(isActive => {
    // Do whatever ist needed
});

// End systemstatus subscription
systemstatusSubscription.endSubscription();

// Call api function
subscriber.callGateway("Cities", "GET", "country/GM", null, function(data) {
    // Process all cities from GM
    return true;
});